@@ -87,6 +87,9 @@ use vars qw(%tags %sets);
 
 # = LIBRARY SECTION ======================================================================
 
+# load modules
+use PerlPoint::Constants 0.14 qw(:tags);
+
 # declare tags - just combining other declarations
 use PerlPoint::Tags::Basic;
 use PerlPoint::Tags::HTML qw(A L PAGEREF SECTIONREF U XREF);
